@@ -206,7 +206,7 @@ vector<vector<double> > pll::get_empirical_frequencies() {
     _check_model_ready();
     double ** ef;
     vector<vector<double>> vec_2d;
-    ef = pllBaseFrequenciesAlignment(alignment, partitions);
+    ef = pllBaseFrequenciesInstance(tr, partitions);
     size_t np = get_number_of_partitions();
     for (size_t i = 0; i < np; ++i) {
         vector<double> row_vec;
@@ -479,6 +479,17 @@ void pll::_init_model(bool parsimony_tree) {
         pllComputeRandomizedStepwiseAdditionParsimonyTree(tr, partitions);
     }
     pllInitModel(tr, partitions);
+
+    if (alignment) {
+        pllAlignmentDataDestroy (alignment);
+        alignment = nullptr;
+    }
+
+    if (newick) {
+        pllNewickParseDestroy (&newick);
+        newick = nullptr;
+    }
+
     _model_ready = true;
 }
 
